@@ -40,37 +40,56 @@ class image:
             return event, x, y, flags
     class trackbar_:
         def defImg(self, img) -> None: self.img = img
-        def __init__(self, name, coos, min=0, max=100, val=0, step=1) -> None:
+        def __init__(self, name, coos, min=0, max=100, val=0) -> None:
             self.name, self.coos = name, coos
-            self.values = [min, max, val, step]
-            self.changing, self.chg_val = False, None
+            self.value = val
+            self.range = (min, max)
+            self.changing = False
         def is_clicked(self, coos) -> bool: return clicked_in(coos, self.coos)
-        def draw(self, col1=COL.red, col2=COL.darkRed, thickness=3, lineType=2, fontSize=1, interligne=0) -> None:
-            self.img.rectangle(*self.coos, col1, 0, lineType)
-            self.img.rectangle(*self.coos, col2, thickness, lineType)
+        def pnts(self, g, d, i, y, n):
+            return (coosCircle(coosCircle(g, dist(g, d)*(i/100), 0), y/n/2, a) for a in (90, 270))
+        def set_vars(self, col1=COL.red, col2=COL.darkRed, col3=COL.green, thickness=3, lineType=2, fontSize=1, interligne=0) -> None:
+            self.col1, self.col2, self.col3 = col1, col2, col3
+            self.tk, self.lt, self.fs, self.il = thickness, lineType, fontSize, interligne
+        def draw(self) -> None: ## TODO Write value, minimum and maximum
+            self.img.rectangle(*self.coos, self.col1, 0, self.lt)
+            self.img.rectangle(*self.coos, self.col2, self.tk, self.lt)
             p1, p4 = self.coos
-            x, y = p4[0]-p1[0], p4[1]-p1[1]
-            g, d = coosCircle(coosCircle(p1, y/2, 90), x/30, 0), coosCircle(coosCircle(p4, y/2, -90), x/30, 180)
-            self.img.line(g, d, col2, thickness, lineType)
+            x, y = diff(p4[0], p1[0]), diff(p4[1], p1[1])
+            dx = x/50
             t = Text(self.name, False)
-            X, Y = t.get_size(fontSize, interligne)
-            t.draw(self.img, (p1[0]+X/2, p1[1]+Y/2), col2, thickness, fontSize, interligne, lineType, 0, True, False)
+            X, Y = t.get_size(self.fs, self.il)
+            t.draw(self.img, (p1[0]+dx, p1[1]+y/2-Y/2), self.col2, self.tk, self.fs, self.il, self.lt, 0, False, False)
+            g, d = (p1[0]+X+dx*2, p1[1]+y/2), (p4[0]-dx, p4[1]-y/2)
+            self.img.line(g, d, self.col2, self.tk, self.lt)
+            m = diff(*self.range)
+            for n, i in enumerate(range(0, m+1, 5)):
+                self.img.line(*self.pnts(g, d, i, y, 2 if n%5==0 else 4), self.col2, self.tk, self.lt)
+            self.img.line(*self.pnts(g, d, self.value, y, 3), self.col3, self.tk, self.lt)
+            self.scale = g[0], d[0]
         def get(self) -> number: return self.val
-    def trackbar(self, name="TrackBar", coos=[[100, 200], [500, 300]], min=0, max=100, val=0, step=1, *args, **kwargs) -> trackbar_:
-        trkb = self.trackbar_(name, coos, min, max, val, step)
+    def trackbar(self, name="TrackBar", coos=[[100, 200], [500, 300]], min=0, max=100, val=0, *args, **kwargs) -> trackbar_:
+        trkb = self.trackbar_(name, coos, min, max, val)
         trkb.defImg(self)
-        trkb.draw(*args, **kwargs)
+        trkb.set_vars(*args, **kwargs)
+        trkb.draw()
         self.trackbars.append(trkb)
         return trkb
+    def remove_trackbar(self, trkb) -> trackbar_ | int:
+        try: return self.trackbars.pop(self.trackbars.index(trkb))
+        except: return -1
     class button_:
         def __init__(self, name, coos) -> None:
             self.name, self.coos = name, coos
             self.functs = []
         def defImg(self, img) -> None: self.img = img
-        def draw(self, col1=COL.red, col2=COL.darkRed, thickness=3, fontSize=1, lineType=2, interligne=0) -> None:
-            self.img.rectangle(*self.coos, col1, 0, 2)
-            self.img.rectangle(*self.coos, col2, thickness, 2)
-            self.img.text(self.name, ct_sg(*self.coos), col2, thickness, fontSize, 0, lineType, True, False, False, interligne)
+        def set_vars(self, col1=COL.red, col2=COL.darkRed, thickness=3, lineType=2, fontSize=1, interligne=0) -> None:
+            self.col1, self.col2 = col1, col2
+            self.tk, self.lt, self.fs, self.il = thickness, lineType, fontSize, interligne
+        def draw(self) -> None:
+            self.img.rectangle(*self.coos, self.col1, 0, 2)
+            self.img.rectangle(*self.coos, self.col2, self.tk, 2)
+            self.img.text(self.name, ct_sg(*self.coos), self.col2, self.tk, self.fs, 0, self.lt, True, False, False, self.il)
         def on_click(self, funct, params=None) -> None:
             '''To add a function to execute when clicked'''
             self.functs.append([funct, params])
@@ -81,7 +100,8 @@ class image:
     def button(self, name="Button", coos=[[100,100], [300, 200]], *args, **kwargs) -> button_:
         bttn = self.button_(name, coos)
         bttn.defImg(self)
-        bttn.draw(*args, **kwargs)
+        bttn.set_vars(*args, **kwargs)
+        bttn.draw()
         self.buttons.append(bttn)
         return bttn
     def remove_button(self, bttn) -> button_ | int:
@@ -99,32 +119,37 @@ class image:
         self.buttons, self.trackbars, self.callbacks = [], [], []
         self.disable_callback = disable_callback
     def __str__(self) -> str: return self.name
-    def show_(self, wait=1, destroy=False, built_in_functs=True) -> int:
+    def show_(self, wait=1, destroy=False, built_in_functs=True, QtGui=False) -> int:
         '''Show image in a window'''
+        props = cv2.WND_PROP_FULLSCREEN | (cv2.WINDOW_GUI_EXPANDED if QtGui else cv2.WINDOW_GUI_NORMAL)
+        cv2.namedWindow(self.name, props)
         if self.fullscreen:
-            cv2.namedWindow(self.name, cv2.WND_PROP_FULLSCREEN)
             cv2.setWindowProperty(self.name, cv2.WND_PROP_FULLSCREEN, cv2.WINDOW_FULLSCREEN)
             cv2.setWindowProperty(self.name, cv2.WND_PROP_ASPECT_RATIO, cv2.WINDOW_KEEPRATIO)
-        else:
-            cv2.namedWindow(self.name, cv2.WND_PROP_FULLSCREEN)
-            cv2.setWindowProperty(self.name, cv2.WND_PROP_FULLSCREEN, cv2.WINDOW_KEEPRATIO)
-        cv2.imshow(self.name, np.array(self.img, np.uint8))
+        else: cv2.setWindowProperty(self.name, cv2.WND_PROP_FULLSCREEN, cv2.WINDOW_KEEPRATIO)
+        cv2.imshow(self.name, cv2.resize(np.array(self.img, np.uint8), RES.resolution))
         wk = cv2.waitKeyEx(wait)
         if not self.disable_callback and self.mouse.new:
+            self.mouse.new = False
             pos = self.mouse.x, self.mouse.y
             v = self.mouse.event, *pos, self.mouse.flags
             for f, p in self.callbacks: f(*v, p)
             for b in self.buttons:
                 if b.is_clicked(pos):
                     b.clicked(v)
-            for t in self.trackbars: ## TODO trackbars' handling
+            for t in self.trackbars:
                 if v[0] == cv2.EVENT_LBUTTONDOWN:
                     if not t.changing and t.is_clicked(pos):
                         t.changing = True
+                elif v[0] == cv2.EVENT_MOUSEMOVE and t.changing:
+                    g, d, x = *t.scale, v[1]
+                    t.value = t.range[0] if x<g else t.range[1] if x>d else diff(g, x)/2
                 elif v[0] == cv2.EVENT_LBUTTONUP:
                     if t.changing:
-                        t.val = t.chg_val
-                        t.changing, t.chg_val = False, None
+                        g, d, x = *t.scale, v[1]
+                        t.value = t.range[0] if x<g else t.range[1] if x>d else diff(g, x)/2
+                        t.changing = False
+                t.draw()
         if destroy == True: cv2.destroyWindow(self.name)
         elif built_in_functs:
             match wk:
@@ -240,13 +265,3 @@ class layout:
         return self.img.is_opened()
     def size(self) -> [int, int]:
         return self.img.size()
-
-if __name__ == "__main__":
-    img = new_img(name="Testing trackbars")
-    fs, tk = 10, 3
-    b = img.button("Test", fontSize=fs, thickness=tk)
-    t = img.trackbar("TEST", fontSize=fs, thickness=tk)
-    img.build()
-    while img.is_opened():
-        wk = img.show()
-        if wk == -1: pass
\ No newline at end of file
